import { IconContext } from "@phosphor-icons/react";
import React from "react";
import {createBrowserRouter, RouterProvider} from "react-router-dom";
import {CurtainsProvider} from "../Components/Curtains/Curtains";
import {NotificationsProvider} from "../Components/Notifications/Notifications";
import {KernelGlobalContextProvider} from "../KernelGlobalContext";

/**
 * Main Kernel UI app component which initializes everything.
 */
export function Kernel({header, footer, router}: {
	header?: React.ReactNode;
	footer?: React.ReactNode;
	router: ReturnType<typeof createBrowserRouter>;
})
{
	return (
		<KernelGlobalContextProvider>
			<IconContext.Provider value={{
				size: "1em",
				weight: "bold",
			}}>
				<NotificationsProvider>
					<CurtainsProvider>
						{header}
						<RouterProvider router={router} />
						{footer}
					</CurtainsProvider>
				</NotificationsProvider>
			</IconContext.Provider>
		</KernelGlobalContextProvider>
	);
}
